Class: Google::Apis::LanguageV1::XpsColumnSpec
- Inherits:
-
Object
- Object
- Google::Apis::LanguageV1::XpsColumnSpec
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/language_v1/classes.rb,
lib/google/apis/language_v1/representations.rb,
lib/google/apis/language_v1/representations.rb
Instance Attribute Summary collapse
-
#column_id ⇒ Fixnum
The unique id of the column.
-
#data_stats ⇒ Google::Apis::LanguageV1::XpsDataStats
The data statistics of a series of values that share the same DataType.
-
#data_type ⇒ Google::Apis::LanguageV1::XpsDataType
Indicated the type of data that can be stored in a structured data entity (e.g. a table).
-
#display_name ⇒ String
The display name of the column.
-
#forecasting_metadata ⇒ Google::Apis::LanguageV1::XpsColumnSpecForecastingMetadata
Corresponds to the JSON property
forecastingMetadata. -
#top_correlated_columns ⇒ Array<Google::Apis::LanguageV1::XpsColumnSpecCorrelatedColumn>
It's outputed in RefreshTablesStats, and a required input in Train.
Instance Method Summary collapse
-
#initialize(**args) ⇒ XpsColumnSpec
constructor
A new instance of XpsColumnSpec.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ XpsColumnSpec
Returns a new instance of XpsColumnSpec.
1663 1664 1665 |
# File 'lib/google/apis/language_v1/classes.rb', line 1663 def initialize(**args) update!(**args) end |
Instance Attribute Details
#column_id ⇒ Fixnum
The unique id of the column. When Preprocess, the Tables BE will popuate the
order id of the column, which reflects the order of the column inside the
table, i.e. 0 means the first column in the table, N-1 means the last column.
AutoML BE will persist this order id in Spanner and set the order id here when
calling RefreshTablesStats and Train. Note: it's different than the
column_spec_id that is generated in AutoML BE.
Corresponds to the JSON property columnId
1634 1635 1636 |
# File 'lib/google/apis/language_v1/classes.rb', line 1634 def column_id @column_id end |
#data_stats ⇒ Google::Apis::LanguageV1::XpsDataStats
The data statistics of a series of values that share the same DataType.
Corresponds to the JSON property dataStats
1639 1640 1641 |
# File 'lib/google/apis/language_v1/classes.rb', line 1639 def data_stats @data_stats end |
#data_type ⇒ Google::Apis::LanguageV1::XpsDataType
Indicated the type of data that can be stored in a structured data entity (e.g.
a table).
Corresponds to the JSON property dataType
1645 1646 1647 |
# File 'lib/google/apis/language_v1/classes.rb', line 1645 def data_type @data_type end |
#display_name ⇒ String
The display name of the column. It's outputed in Preprocess and a required
input for RefreshTablesStats and Train.
Corresponds to the JSON property displayName
1651 1652 1653 |
# File 'lib/google/apis/language_v1/classes.rb', line 1651 def display_name @display_name end |
#forecasting_metadata ⇒ Google::Apis::LanguageV1::XpsColumnSpecForecastingMetadata
Corresponds to the JSON property forecastingMetadata
1656 1657 1658 |
# File 'lib/google/apis/language_v1/classes.rb', line 1656 def @forecasting_metadata end |
#top_correlated_columns ⇒ Array<Google::Apis::LanguageV1::XpsColumnSpecCorrelatedColumn>
It's outputed in RefreshTablesStats, and a required input in Train.
Corresponds to the JSON property topCorrelatedColumns
1661 1662 1663 |
# File 'lib/google/apis/language_v1/classes.rb', line 1661 def @top_correlated_columns end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1668 1669 1670 1671 1672 1673 1674 1675 |
# File 'lib/google/apis/language_v1/classes.rb', line 1668 def update!(**args) @column_id = args[:column_id] if args.key?(:column_id) @data_stats = args[:data_stats] if args.key?(:data_stats) @data_type = args[:data_type] if args.key?(:data_type) @display_name = args[:display_name] if args.key?(:display_name) @forecasting_metadata = args[:forecasting_metadata] if args.key?(:forecasting_metadata) @top_correlated_columns = args[:top_correlated_columns] if args.key?(:top_correlated_columns) end |