Class: Google::Apis::LanguageV1::XpsEvaluationMetrics

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/language_v1/classes.rb,
lib/google/apis/language_v1/representations.rb,
lib/google/apis/language_v1/representations.rb

Overview

Contains xPS-specific model evaluation metrics either for a single annotation spec (label), or for the model overall. Next tag: 18.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ XpsEvaluationMetrics

Returns a new instance of XpsEvaluationMetrics.



2268
2269
2270
# File 'lib/google/apis/language_v1/classes.rb', line 2268

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#annotation_spec_id_tokenString

The annotation_spec for which this evaluation metrics instance had been created. Empty iff this is an overall model evaluation (like Tables evaluation metrics), i.e. aggregated across all labels. The value comes from the input annotations in AnnotatedExample. For MVP product or for text sentiment models where annotation_spec_id_token is not available, set label instead. Corresponds to the JSON property annotationSpecIdToken

Returns:

  • (String)


2173
2174
2175
# File 'lib/google/apis/language_v1/classes.rb', line 2173

def annotation_spec_id_token
  @annotation_spec_id_token
end

#categoryFixnum

The integer category label for which this evaluation metric instance had been created. Valid categories are 0 or higher. Overall model evaluation should set this to negative values (rather than implicit zero). Only used for Image Segmentation (prefer to set annotation_spec_id_token instead). Note: uCAIP Image Segmentation should use annotation_spec_id_token. Corresponds to the JSON property category

Returns:

  • (Fixnum)


2182
2183
2184
# File 'lib/google/apis/language_v1/classes.rb', line 2182

def category
  @category
end

#evaluated_example_countFixnum

The number of examples used to create this evaluation metrics instance. Corresponds to the JSON property evaluatedExampleCount

Returns:

  • (Fixnum)


2187
2188
2189
# File 'lib/google/apis/language_v1/classes.rb', line 2187

def evaluated_example_count
  @evaluated_example_count
end

#image_classification_eval_metricsGoogle::Apis::LanguageV1::XpsClassificationEvaluationMetrics

Model evaluation metrics for classification problems. It can be used for image and video classification. Next tag: 9. Corresponds to the JSON property imageClassificationEvalMetrics



2193
2194
2195
# File 'lib/google/apis/language_v1/classes.rb', line 2193

def image_classification_eval_metrics
  @image_classification_eval_metrics
end

#image_object_detection_eval_metricsGoogle::Apis::LanguageV1::XpsImageObjectDetectionEvaluationMetrics

Model evaluation metrics for image object detection problems. Evaluates prediction quality of labeled bounding boxes. Corresponds to the JSON property imageObjectDetectionEvalMetrics



2199
2200
2201
# File 'lib/google/apis/language_v1/classes.rb', line 2199

def image_object_detection_eval_metrics
  @image_object_detection_eval_metrics
end

#image_segmentation_eval_metricsGoogle::Apis::LanguageV1::XpsImageSegmentationEvaluationMetrics

Model evaluation metrics for image segmentation problems. Next tag: 4. Corresponds to the JSON property imageSegmentationEvalMetrics



2204
2205
2206
# File 'lib/google/apis/language_v1/classes.rb', line 2204

def image_segmentation_eval_metrics
  @image_segmentation_eval_metrics
end

#labelString

The label for which this evaluation metrics instance had been created. Empty iff this is an overall model evaluation (like Tables evaluation metrics), i.e. aggregated across all labels. The label maps to AnnotationSpec.display_name in Public API protos. Only used by MVP implementation and text sentiment FULL implementation. Corresponds to the JSON property label

Returns:

  • (String)


2213
2214
2215
# File 'lib/google/apis/language_v1/classes.rb', line 2213

def label
  @label
end

#regression_eval_metricsGoogle::Apis::LanguageV1::XpsRegressionEvaluationMetrics

Model evaluation metrics for regression problems. It can be used for Tables. Corresponds to the JSON property regressionEvalMetrics



2218
2219
2220
# File 'lib/google/apis/language_v1/classes.rb', line 2218

def regression_eval_metrics
  @regression_eval_metrics
end

#tables_classification_eval_metricsGoogle::Apis::LanguageV1::XpsClassificationEvaluationMetrics

Model evaluation metrics for classification problems. It can be used for image and video classification. Next tag: 9. Corresponds to the JSON property tablesClassificationEvalMetrics



2224
2225
2226
# File 'lib/google/apis/language_v1/classes.rb', line 2224

def tables_classification_eval_metrics
  @tables_classification_eval_metrics
end

#tables_eval_metricsGoogle::Apis::LanguageV1::XpsTablesEvaluationMetrics

Corresponds to the JSON property tablesEvalMetrics



2229
2230
2231
# File 'lib/google/apis/language_v1/classes.rb', line 2229

def tables_eval_metrics
  @tables_eval_metrics
end

#text_classification_eval_metricsGoogle::Apis::LanguageV1::XpsClassificationEvaluationMetrics

Model evaluation metrics for classification problems. It can be used for image and video classification. Next tag: 9. Corresponds to the JSON property textClassificationEvalMetrics



2235
2236
2237
# File 'lib/google/apis/language_v1/classes.rb', line 2235

def text_classification_eval_metrics
  @text_classification_eval_metrics
end

#text_extraction_eval_metricsGoogle::Apis::LanguageV1::XpsTextExtractionEvaluationMetrics

Corresponds to the JSON property textExtractionEvalMetrics



2240
2241
2242
# File 'lib/google/apis/language_v1/classes.rb', line 2240

def text_extraction_eval_metrics
  @text_extraction_eval_metrics
end

#text_sentiment_eval_metricsGoogle::Apis::LanguageV1::XpsTextSentimentEvaluationMetrics

Model evaluation metrics for text sentiment problems. Corresponds to the JSON property textSentimentEvalMetrics



2245
2246
2247
# File 'lib/google/apis/language_v1/classes.rb', line 2245

def text_sentiment_eval_metrics
  @text_sentiment_eval_metrics
end

#translation_eval_metricsGoogle::Apis::LanguageV1::XpsTranslationEvaluationMetrics

Evaluation metrics for the dataset. Corresponds to the JSON property translationEvalMetrics



2250
2251
2252
# File 'lib/google/apis/language_v1/classes.rb', line 2250

def translation_eval_metrics
  @translation_eval_metrics
end

#video_action_recognition_eval_metricsGoogle::Apis::LanguageV1::XpsVideoActionRecognitionEvaluationMetrics

Model evaluation metrics for video action recognition. Corresponds to the JSON property videoActionRecognitionEvalMetrics



2255
2256
2257
# File 'lib/google/apis/language_v1/classes.rb', line 2255

def video_action_recognition_eval_metrics
  @video_action_recognition_eval_metrics
end

#video_classification_eval_metricsGoogle::Apis::LanguageV1::XpsClassificationEvaluationMetrics

Model evaluation metrics for classification problems. It can be used for image and video classification. Next tag: 9. Corresponds to the JSON property videoClassificationEvalMetrics



2261
2262
2263
# File 'lib/google/apis/language_v1/classes.rb', line 2261

def video_classification_eval_metrics
  @video_classification_eval_metrics
end

#video_object_tracking_eval_metricsGoogle::Apis::LanguageV1::XpsVideoObjectTrackingEvaluationMetrics

Model evaluation metrics for ObjectTracking problems. Next tag: 10. Corresponds to the JSON property videoObjectTrackingEvalMetrics



2266
2267
2268
# File 'lib/google/apis/language_v1/classes.rb', line 2266

def video_object_tracking_eval_metrics
  @video_object_tracking_eval_metrics
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2273
2274
2275
2276
2277
2278
2279
2280
2281
2282
2283
2284
2285
2286
2287
2288
2289
2290
2291
# File 'lib/google/apis/language_v1/classes.rb', line 2273

def update!(**args)
  @annotation_spec_id_token = args[:annotation_spec_id_token] if args.key?(:annotation_spec_id_token)
  @category = args[:category] if args.key?(:category)
  @evaluated_example_count = args[:evaluated_example_count] if args.key?(:evaluated_example_count)
  @image_classification_eval_metrics = args[:image_classification_eval_metrics] if args.key?(:image_classification_eval_metrics)
  @image_object_detection_eval_metrics = args[:image_object_detection_eval_metrics] if args.key?(:image_object_detection_eval_metrics)
  @image_segmentation_eval_metrics = args[:image_segmentation_eval_metrics] if args.key?(:image_segmentation_eval_metrics)
  @label = args[:label] if args.key?(:label)
  @regression_eval_metrics = args[:regression_eval_metrics] if args.key?(:regression_eval_metrics)
  @tables_classification_eval_metrics = args[:tables_classification_eval_metrics] if args.key?(:tables_classification_eval_metrics)
  @tables_eval_metrics = args[:tables_eval_metrics] if args.key?(:tables_eval_metrics)
  @text_classification_eval_metrics = args[:text_classification_eval_metrics] if args.key?(:text_classification_eval_metrics)
  @text_extraction_eval_metrics = args[:text_extraction_eval_metrics] if args.key?(:text_extraction_eval_metrics)
  @text_sentiment_eval_metrics = args[:text_sentiment_eval_metrics] if args.key?(:text_sentiment_eval_metrics)
  @translation_eval_metrics = args[:translation_eval_metrics] if args.key?(:translation_eval_metrics)
  @video_action_recognition_eval_metrics = args[:video_action_recognition_eval_metrics] if args.key?(:video_action_recognition_eval_metrics)
  @video_classification_eval_metrics = args[:video_classification_eval_metrics] if args.key?(:video_classification_eval_metrics)
  @video_object_tracking_eval_metrics = args[:video_object_tracking_eval_metrics] if args.key?(:video_object_tracking_eval_metrics)
end