Class: Google::Apis::LanguageV1::XpsFloat64Stats
- Inherits:
-
Object
- Object
- Google::Apis::LanguageV1::XpsFloat64Stats
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/language_v1/classes.rb,
lib/google/apis/language_v1/representations.rb,
lib/google/apis/language_v1/representations.rb
Overview
The data statistics of a series of FLOAT64 values.
Instance Attribute Summary collapse
-
#common_stats ⇒ Google::Apis::LanguageV1::XpsCommonStats
Common statistics for a column with a specified data type.
-
#histogram_buckets ⇒ Array<Google::Apis::LanguageV1::XpsFloat64StatsHistogramBucket>
Histogram buckets of the data series.
-
#mean ⇒ Float
The mean of the series.
-
#quantiles ⇒ Array<Float>
Ordered from 0 to k k-quantile values of the data series of n values.
-
#standard_deviation ⇒ Float
The standard deviation of the series.
Instance Method Summary collapse
-
#initialize(**args) ⇒ XpsFloat64Stats
constructor
A new instance of XpsFloat64Stats.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ XpsFloat64Stats
Returns a new instance of XpsFloat64Stats.
2515 2516 2517 |
# File 'lib/google/apis/language_v1/classes.rb', line 2515 def initialize(**args) update!(**args) end |
Instance Attribute Details
#common_stats ⇒ Google::Apis::LanguageV1::XpsCommonStats
Common statistics for a column with a specified data type.
Corresponds to the JSON property commonStats
2487 2488 2489 |
# File 'lib/google/apis/language_v1/classes.rb', line 2487 def common_stats @common_stats end |
#histogram_buckets ⇒ Array<Google::Apis::LanguageV1::XpsFloat64StatsHistogramBucket>
Histogram buckets of the data series. Sorted by the min value of the bucket,
ascendingly, and the number of the buckets is dynamically generated. The
buckets are non-overlapping and completely cover whole FLOAT64 range with min
of first bucket being "-Infinity", and max of the last one being "Infinity"
.
Corresponds to the JSON property histogramBuckets
2496 2497 2498 |
# File 'lib/google/apis/language_v1/classes.rb', line 2496 def histogram_buckets @histogram_buckets end |
#mean ⇒ Float
The mean of the series.
Corresponds to the JSON property mean
2501 2502 2503 |
# File 'lib/google/apis/language_v1/classes.rb', line 2501 def mean @mean end |
#quantiles ⇒ Array<Float>
Ordered from 0 to k k-quantile values of the data series of n values. The
value at index i is, approximately, the i*n/k-th smallest value in the series;
for i = 0 and i = k these are, respectively, the min and max values.
Corresponds to the JSON property quantiles
2508 2509 2510 |
# File 'lib/google/apis/language_v1/classes.rb', line 2508 def quantiles @quantiles end |
#standard_deviation ⇒ Float
The standard deviation of the series.
Corresponds to the JSON property standardDeviation
2513 2514 2515 |
# File 'lib/google/apis/language_v1/classes.rb', line 2513 def standard_deviation @standard_deviation end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2520 2521 2522 2523 2524 2525 2526 |
# File 'lib/google/apis/language_v1/classes.rb', line 2520 def update!(**args) @common_stats = args[:common_stats] if args.key?(:common_stats) @histogram_buckets = args[:histogram_buckets] if args.key?(:histogram_buckets) @mean = args[:mean] if args.key?(:mean) @quantiles = args[:quantiles] if args.key?(:quantiles) @standard_deviation = args[:standard_deviation] if args.key?(:standard_deviation) end |