Class: Google::Apis::LanguageV1::XpsImageExportModelSpec
- Inherits:
-
Object
- Object
- Google::Apis::LanguageV1::XpsImageExportModelSpec
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/language_v1/classes.rb,
lib/google/apis/language_v1/representations.rb,
lib/google/apis/language_v1/representations.rb
Overview
Information of downloadable models that are pre-generated as part of training flow and will be persisted in AutoMl backend. Upon receiving ExportModel request from user, AutoMl backend can serve the pre-generated models to user if exists (by copying the files from internal path to user provided location), otherwise, AutoMl backend will call xPS ExportModel API to generate the model on the fly with the requesting format.
Instance Attribute Summary collapse
-
#export_model_output_config ⇒ Array<Google::Apis::LanguageV1::XpsExportModelOutputConfig>
Contains the model format and internal location of the model files to be exported/downloaded.
Instance Method Summary collapse
-
#initialize(**args) ⇒ XpsImageExportModelSpec
constructor
A new instance of XpsImageExportModelSpec.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ XpsImageExportModelSpec
Returns a new instance of XpsImageExportModelSpec.
2644 2645 2646 |
# File 'lib/google/apis/language_v1/classes.rb', line 2644 def initialize(**args) update!(**args) end |
Instance Attribute Details
#export_model_output_config ⇒ Array<Google::Apis::LanguageV1::XpsExportModelOutputConfig>
Contains the model format and internal location of the model files to be
exported/downloaded. Use the Google Cloud Storage bucket name which is
provided via TrainRequest.gcs_bucket_name to store the model files.
Corresponds to the JSON property exportModelOutputConfig
2642 2643 2644 |
# File 'lib/google/apis/language_v1/classes.rb', line 2642 def export_model_output_config @export_model_output_config end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2649 2650 2651 |
# File 'lib/google/apis/language_v1/classes.rb', line 2649 def update!(**args) @export_model_output_config = args[:export_model_output_config] if args.key?(:export_model_output_config) end |