Class: Google::Apis::LanguageV1::XpsImageSegmentationEvaluationMetricsConfidenceMetricsEntry
- Inherits:
-
Object
- Object
- Google::Apis::LanguageV1::XpsImageSegmentationEvaluationMetricsConfidenceMetricsEntry
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/language_v1/classes.rb,
lib/google/apis/language_v1/representations.rb,
lib/google/apis/language_v1/representations.rb
Overview
Metrics for a single confidence threshold.
Instance Attribute Summary collapse
-
#confidence_threshold ⇒ Float
The confidence threshold value used to compute the metrics.
-
#confusion_matrix ⇒ Google::Apis::LanguageV1::XpsConfusionMatrix
Confusion matrix of the model running the classification.
-
#dice_score_coefficient ⇒ Float
DSC or the F1 score: The harmonic mean of recall and precision.
-
#iou_score ⇒ Float
IOU score.
-
#precision ⇒ Float
Precision for the given confidence threshold.
-
#recall ⇒ Float
Recall for the given confidence threshold.
Instance Method Summary collapse
-
#initialize(**args) ⇒ XpsImageSegmentationEvaluationMetricsConfidenceMetricsEntry
constructor
A new instance of XpsImageSegmentationEvaluationMetricsConfidenceMetricsEntry.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ XpsImageSegmentationEvaluationMetricsConfidenceMetricsEntry
Returns a new instance of XpsImageSegmentationEvaluationMetricsConfidenceMetricsEntry.
2927 2928 2929 |
# File 'lib/google/apis/language_v1/classes.rb', line 2927 def initialize(**args) update!(**args) end |
Instance Attribute Details
#confidence_threshold ⇒ Float
The confidence threshold value used to compute the metrics.
Corresponds to the JSON property confidenceThreshold
2900 2901 2902 |
# File 'lib/google/apis/language_v1/classes.rb', line 2900 def confidence_threshold @confidence_threshold end |
#confusion_matrix ⇒ Google::Apis::LanguageV1::XpsConfusionMatrix
Confusion matrix of the model running the classification.
Corresponds to the JSON property confusionMatrix
2905 2906 2907 |
# File 'lib/google/apis/language_v1/classes.rb', line 2905 def confusion_matrix @confusion_matrix end |
#dice_score_coefficient ⇒ Float
DSC or the F1 score: The harmonic mean of recall and precision.
Corresponds to the JSON property diceScoreCoefficient
2910 2911 2912 |
# File 'lib/google/apis/language_v1/classes.rb', line 2910 def dice_score_coefficient @dice_score_coefficient end |
#iou_score ⇒ Float
IOU score.
Corresponds to the JSON property iouScore
2915 2916 2917 |
# File 'lib/google/apis/language_v1/classes.rb', line 2915 def iou_score @iou_score end |
#precision ⇒ Float
Precision for the given confidence threshold.
Corresponds to the JSON property precision
2920 2921 2922 |
# File 'lib/google/apis/language_v1/classes.rb', line 2920 def precision @precision end |
#recall ⇒ Float
Recall for the given confidence threshold.
Corresponds to the JSON property recall
2925 2926 2927 |
# File 'lib/google/apis/language_v1/classes.rb', line 2925 def recall @recall end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2932 2933 2934 2935 2936 2937 2938 2939 |
# File 'lib/google/apis/language_v1/classes.rb', line 2932 def update!(**args) @confidence_threshold = args[:confidence_threshold] if args.key?(:confidence_threshold) @confusion_matrix = args[:confusion_matrix] if args.key?(:confusion_matrix) @dice_score_coefficient = args[:dice_score_coefficient] if args.key?(:dice_score_coefficient) @iou_score = args[:iou_score] if args.key?(:iou_score) @precision = args[:precision] if args.key?(:precision) @recall = args[:recall] if args.key?(:recall) end |