Class: Google::Apis::LanguageV1::XpsImageSegmentationTrainResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/language_v1/classes.rb,
lib/google/apis/language_v1/representations.rb,
lib/google/apis/language_v1/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ XpsImageSegmentationTrainResponse

Returns a new instance of XpsImageSegmentationTrainResponse.



2983
2984
2985
# File 'lib/google/apis/language_v1/classes.rb', line 2983

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#color_mapsArray<Google::Apis::LanguageV1::XpsColorMap>

Color map of the model. Corresponds to the JSON property colorMaps



2949
2950
2951
# File 'lib/google/apis/language_v1/classes.rb', line 2949

def color_maps
  @color_maps
end

#export_model_specGoogle::Apis::LanguageV1::XpsImageExportModelSpec

Information of downloadable models that are pre-generated as part of training flow and will be persisted in AutoMl backend. Upon receiving ExportModel request from user, AutoMl backend can serve the pre-generated models to user if exists (by copying the files from internal path to user provided location), otherwise, AutoMl backend will call xPS ExportModel API to generate the model on the fly with the requesting format. Corresponds to the JSON property exportModelSpec



2959
2960
2961
# File 'lib/google/apis/language_v1/classes.rb', line 2959

def export_model_spec
  @export_model_spec
end

#model_artifact_specGoogle::Apis::LanguageV1::XpsImageModelArtifactSpec

Stores the locations and related metadata of the model artifacts. Populated for uCAIP requests only. Corresponds to the JSON property modelArtifactSpec



2965
2966
2967
# File 'lib/google/apis/language_v1/classes.rb', line 2965

def model_artifact_spec
  @model_artifact_spec
end

#model_serving_specGoogle::Apis::LanguageV1::XpsImageModelServingSpec

Serving specification for image models. Corresponds to the JSON property modelServingSpec



2970
2971
2972
# File 'lib/google/apis/language_v1/classes.rb', line 2970

def model_serving_spec
  @model_serving_spec
end

#stop_reasonString

Stop reason for training job, e.g. 'TRAIN_BUDGET_REACHED', 'MODEL_CONVERGED'. Corresponds to the JSON property stopReason

Returns:

  • (String)


2975
2976
2977
# File 'lib/google/apis/language_v1/classes.rb', line 2975

def stop_reason
  @stop_reason
end

#train_cost_node_secondsFixnum

The actual train cost of creating this model, expressed in node seconds, i.e. 3,600 value in this field means 1 node hour. Corresponds to the JSON property trainCostNodeSeconds

Returns:

  • (Fixnum)


2981
2982
2983
# File 'lib/google/apis/language_v1/classes.rb', line 2981

def train_cost_node_seconds
  @train_cost_node_seconds
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2988
2989
2990
2991
2992
2993
2994
2995
# File 'lib/google/apis/language_v1/classes.rb', line 2988

def update!(**args)
  @color_maps = args[:color_maps] if args.key?(:color_maps)
  @export_model_spec = args[:export_model_spec] if args.key?(:export_model_spec)
  @model_artifact_spec = args[:model_artifact_spec] if args.key?(:model_artifact_spec)
  @model_serving_spec = args[:model_serving_spec] if args.key?(:model_serving_spec)
  @stop_reason = args[:stop_reason] if args.key?(:stop_reason)
  @train_cost_node_seconds = args[:train_cost_node_seconds] if args.key?(:train_cost_node_seconds)
end