Class: Google::Apis::LanguageV1::XpsRegressionMetricsEntry
- Inherits:
-
Object
- Object
- Google::Apis::LanguageV1::XpsRegressionMetricsEntry
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/language_v1/classes.rb,
lib/google/apis/language_v1/representations.rb,
lib/google/apis/language_v1/representations.rb
Overview
A pair of actual & observed values for the model being evaluated.
Instance Attribute Summary collapse
-
#predicted_value ⇒ Float
The observed value for a row in the dataset.
-
#true_value ⇒ Float
The actual target value for a row in the dataset.
Instance Method Summary collapse
-
#initialize(**args) ⇒ XpsRegressionMetricsEntry
constructor
A new instance of XpsRegressionMetricsEntry.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ XpsRegressionMetricsEntry
Returns a new instance of XpsRegressionMetricsEntry.
3217 3218 3219 |
# File 'lib/google/apis/language_v1/classes.rb', line 3217 def initialize(**args) update!(**args) end |
Instance Attribute Details
#predicted_value ⇒ Float
The observed value for a row in the dataset.
Corresponds to the JSON property predictedValue
3210 3211 3212 |
# File 'lib/google/apis/language_v1/classes.rb', line 3210 def predicted_value @predicted_value end |
#true_value ⇒ Float
The actual target value for a row in the dataset.
Corresponds to the JSON property trueValue
3215 3216 3217 |
# File 'lib/google/apis/language_v1/classes.rb', line 3215 def true_value @true_value end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3222 3223 3224 3225 |
# File 'lib/google/apis/language_v1/classes.rb', line 3222 def update!(**args) @predicted_value = args[:predicted_value] if args.key?(:predicted_value) @true_value = args[:true_value] if args.key?(:true_value) end |