Class: Google::Apis::LanguageV1::XpsSpeechEvaluationMetricsSubModelEvaluationMetric
- Inherits:
-
Object
- Object
- Google::Apis::LanguageV1::XpsSpeechEvaluationMetricsSubModelEvaluationMetric
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/language_v1/classes.rb,
lib/google/apis/language_v1/representations.rb,
lib/google/apis/language_v1/representations.rb
Instance Attribute Summary collapse
-
#biasing_model_type ⇒ String
Type of the biasing model.
-
#is_enhanced_model ⇒ Boolean
(also: #is_enhanced_model?)
If true then it means we have an enhanced version of the biasing models.
-
#num_deletions ⇒ Fixnum
Corresponds to the JSON property
numDeletions. -
#num_insertions ⇒ Fixnum
Corresponds to the JSON property
numInsertions. -
#num_substitutions ⇒ Fixnum
Corresponds to the JSON property
numSubstitutions. -
#num_utterances ⇒ Fixnum
Number of utterances used in the wer computation.
-
#num_words ⇒ Fixnum
Number of words over which the word error rate was computed.
-
#sentence_accuracy ⇒ Float
Below fields are used for debugging purposes Corresponds to the JSON property
sentenceAccuracy. -
#wer ⇒ Float
Word error rate (standard error metric used for speech recognition).
Instance Method Summary collapse
-
#initialize(**args) ⇒ XpsSpeechEvaluationMetricsSubModelEvaluationMetric
constructor
A new instance of XpsSpeechEvaluationMetricsSubModelEvaluationMetric.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ XpsSpeechEvaluationMetricsSubModelEvaluationMetric
Returns a new instance of XpsSpeechEvaluationMetricsSubModelEvaluationMetric.
3489 3490 3491 |
# File 'lib/google/apis/language_v1/classes.rb', line 3489 def initialize(**args) update!(**args) end |
Instance Attribute Details
#biasing_model_type ⇒ String
Type of the biasing model.
Corresponds to the JSON property biasingModelType
3446 3447 3448 |
# File 'lib/google/apis/language_v1/classes.rb', line 3446 def biasing_model_type @biasing_model_type end |
#is_enhanced_model ⇒ Boolean Also known as: is_enhanced_model?
If true then it means we have an enhanced version of the biasing models.
Corresponds to the JSON property isEnhancedModel
3451 3452 3453 |
# File 'lib/google/apis/language_v1/classes.rb', line 3451 def is_enhanced_model @is_enhanced_model end |
#num_deletions ⇒ Fixnum
Corresponds to the JSON property numDeletions
3457 3458 3459 |
# File 'lib/google/apis/language_v1/classes.rb', line 3457 def num_deletions @num_deletions end |
#num_insertions ⇒ Fixnum
Corresponds to the JSON property numInsertions
3462 3463 3464 |
# File 'lib/google/apis/language_v1/classes.rb', line 3462 def num_insertions @num_insertions end |
#num_substitutions ⇒ Fixnum
Corresponds to the JSON property numSubstitutions
3467 3468 3469 |
# File 'lib/google/apis/language_v1/classes.rb', line 3467 def num_substitutions @num_substitutions end |
#num_utterances ⇒ Fixnum
Number of utterances used in the wer computation.
Corresponds to the JSON property numUtterances
3472 3473 3474 |
# File 'lib/google/apis/language_v1/classes.rb', line 3472 def num_utterances @num_utterances end |
#num_words ⇒ Fixnum
Number of words over which the word error rate was computed.
Corresponds to the JSON property numWords
3477 3478 3479 |
# File 'lib/google/apis/language_v1/classes.rb', line 3477 def num_words @num_words end |
#sentence_accuracy ⇒ Float
Below fields are used for debugging purposes
Corresponds to the JSON property sentenceAccuracy
3482 3483 3484 |
# File 'lib/google/apis/language_v1/classes.rb', line 3482 def sentence_accuracy @sentence_accuracy end |
#wer ⇒ Float
Word error rate (standard error metric used for speech recognition).
Corresponds to the JSON property wer
3487 3488 3489 |
# File 'lib/google/apis/language_v1/classes.rb', line 3487 def wer @wer end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3494 3495 3496 3497 3498 3499 3500 3501 3502 3503 3504 |
# File 'lib/google/apis/language_v1/classes.rb', line 3494 def update!(**args) @biasing_model_type = args[:biasing_model_type] if args.key?(:biasing_model_type) @is_enhanced_model = args[:is_enhanced_model] if args.key?(:is_enhanced_model) @num_deletions = args[:num_deletions] if args.key?(:num_deletions) @num_insertions = args[:num_insertions] if args.key?(:num_insertions) @num_substitutions = args[:num_substitutions] if args.key?(:num_substitutions) @num_utterances = args[:num_utterances] if args.key?(:num_utterances) @num_words = args[:num_words] if args.key?(:num_words) @sentence_accuracy = args[:sentence_accuracy] if args.key?(:sentence_accuracy) @wer = args[:wer] if args.key?(:wer) end |