Class: Google::Apis::LanguageV1::XpsStringStats
- Inherits:
-
Object
- Object
- Google::Apis::LanguageV1::XpsStringStats
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/language_v1/classes.rb,
lib/google/apis/language_v1/representations.rb,
lib/google/apis/language_v1/representations.rb
Overview
The data statistics of a series of STRING values.
Instance Attribute Summary collapse
-
#common_stats ⇒ Google::Apis::LanguageV1::XpsCommonStats
Common statistics for a column with a specified data type.
-
#top_unigram_stats ⇒ Array<Google::Apis::LanguageV1::XpsStringStatsUnigramStats>
The statistics of the top 20 unigrams, ordered by StringStats.UnigramStats.
Instance Method Summary collapse
-
#initialize(**args) ⇒ XpsStringStats
constructor
A new instance of XpsStringStats.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ XpsStringStats
Returns a new instance of XpsStringStats.
3703 3704 3705 |
# File 'lib/google/apis/language_v1/classes.rb', line 3703 def initialize(**args) update!(**args) end |
Instance Attribute Details
#common_stats ⇒ Google::Apis::LanguageV1::XpsCommonStats
Common statistics for a column with a specified data type.
Corresponds to the JSON property commonStats
3695 3696 3697 |
# File 'lib/google/apis/language_v1/classes.rb', line 3695 def common_stats @common_stats end |
#top_unigram_stats ⇒ Array<Google::Apis::LanguageV1::XpsStringStatsUnigramStats>
The statistics of the top 20 unigrams, ordered by StringStats.UnigramStats.
count.
Corresponds to the JSON property topUnigramStats
3701 3702 3703 |
# File 'lib/google/apis/language_v1/classes.rb', line 3701 def top_unigram_stats @top_unigram_stats end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3708 3709 3710 3711 |
# File 'lib/google/apis/language_v1/classes.rb', line 3708 def update!(**args) @common_stats = args[:common_stats] if args.key?(:common_stats) @top_unigram_stats = args[:top_unigram_stats] if args.key?(:top_unigram_stats) end |