Class: Google::Apis::LanguageV1::XpsStringStatsUnigramStats
- Inherits:
-
Object
- Object
- Google::Apis::LanguageV1::XpsStringStatsUnigramStats
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/language_v1/classes.rb,
lib/google/apis/language_v1/representations.rb,
lib/google/apis/language_v1/representations.rb
Overview
The statistics of a unigram.
Instance Attribute Summary collapse
-
#count ⇒ Fixnum
The number of occurrences of this unigram in the series.
-
#value ⇒ String
The unigram.
Instance Method Summary collapse
-
#initialize(**args) ⇒ XpsStringStatsUnigramStats
constructor
A new instance of XpsStringStatsUnigramStats.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ XpsStringStatsUnigramStats
Returns a new instance of XpsStringStatsUnigramStats.
3728 3729 3730 |
# File 'lib/google/apis/language_v1/classes.rb', line 3728 def initialize(**args) update!(**args) end |
Instance Attribute Details
#count ⇒ Fixnum
The number of occurrences of this unigram in the series.
Corresponds to the JSON property count
3721 3722 3723 |
# File 'lib/google/apis/language_v1/classes.rb', line 3721 def count @count end |
#value ⇒ String
The unigram.
Corresponds to the JSON property value
3726 3727 3728 |
# File 'lib/google/apis/language_v1/classes.rb', line 3726 def value @value end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3733 3734 3735 3736 |
# File 'lib/google/apis/language_v1/classes.rb', line 3733 def update!(**args) @count = args[:count] if args.key?(:count) @value = args[:value] if args.key?(:value) end |