Class: Google::Apis::LanguageV1::XpsStructStats

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/language_v1/classes.rb,
lib/google/apis/language_v1/representations.rb,
lib/google/apis/language_v1/representations.rb

Overview

The data statistics of a series of STRUCT values.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ XpsStructStats

Returns a new instance of XpsStructStats.



3754
3755
3756
# File 'lib/google/apis/language_v1/classes.rb', line 3754

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#common_statsGoogle::Apis::LanguageV1::XpsCommonStats

Common statistics for a column with a specified data type. Corresponds to the JSON property commonStats



3746
3747
3748
# File 'lib/google/apis/language_v1/classes.rb', line 3746

def common_stats
  @common_stats
end

#field_statsHash<String,Google::Apis::LanguageV1::XpsDataStats>

Map from a field name of the struct to data stats aggregated over series of all data in that field across all the structs. Corresponds to the JSON property fieldStats

Returns:



3752
3753
3754
# File 'lib/google/apis/language_v1/classes.rb', line 3752

def field_stats
  @field_stats
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3759
3760
3761
3762
# File 'lib/google/apis/language_v1/classes.rb', line 3759

def update!(**args)
  @common_stats = args[:common_stats] if args.key?(:common_stats)
  @field_stats = args[:field_stats] if args.key?(:field_stats)
end