Class: Google::Apis::LanguageV1::XpsTablesDatasetMetadata

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/language_v1/classes.rb,
lib/google/apis/language_v1/representations.rb,
lib/google/apis/language_v1/representations.rb

Overview

Metadata for a dataset used for AutoML Tables.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ XpsTablesDatasetMetadata

Returns a new instance of XpsTablesDatasetMetadata.



3999
4000
4001
# File 'lib/google/apis/language_v1/classes.rb', line 3999

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#ml_use_column_idFixnum

Id the column to split the table. Corresponds to the JSON property mlUseColumnId

Returns:

  • (Fixnum)


3977
3978
3979
# File 'lib/google/apis/language_v1/classes.rb', line 3977

def ml_use_column_id
  @ml_use_column_id
end

#primary_table_specGoogle::Apis::LanguageV1::XpsTableSpec

Primary table. Corresponds to the JSON property primaryTableSpec



3982
3983
3984
# File 'lib/google/apis/language_v1/classes.rb', line 3982

def primary_table_spec
  @primary_table_spec
end

#target_column_correlationsHash<String,Google::Apis::LanguageV1::XpsCorrelationStats>

(the column id : its CorrelationStats with target column). Corresponds to the JSON property targetColumnCorrelations



3987
3988
3989
# File 'lib/google/apis/language_v1/classes.rb', line 3987

def target_column_correlations
  @target_column_correlations
end

#target_column_idFixnum

Id of the primary table column that should be used as the training label. Corresponds to the JSON property targetColumnId

Returns:

  • (Fixnum)


3992
3993
3994
# File 'lib/google/apis/language_v1/classes.rb', line 3992

def target_column_id
  @target_column_id
end

#weight_column_idFixnum

Id of the primary table column that should be used as the weight column. Corresponds to the JSON property weightColumnId

Returns:

  • (Fixnum)


3997
3998
3999
# File 'lib/google/apis/language_v1/classes.rb', line 3997

def weight_column_id
  @weight_column_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4004
4005
4006
4007
4008
4009
4010
# File 'lib/google/apis/language_v1/classes.rb', line 4004

def update!(**args)
  @ml_use_column_id = args[:ml_use_column_id] if args.key?(:ml_use_column_id)
  @primary_table_spec = args[:primary_table_spec] if args.key?(:primary_table_spec)
  @target_column_correlations = args[:target_column_correlations] if args.key?(:target_column_correlations)
  @target_column_id = args[:target_column_id] if args.key?(:target_column_id)
  @weight_column_id = args[:weight_column_id] if args.key?(:weight_column_id)
end