Class: Google::Apis::LanguageV1::XpsTablesTrainingOperationMetadata

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/language_v1/classes.rb,
lib/google/apis/language_v1/representations.rb,
lib/google/apis/language_v1/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ XpsTablesTrainingOperationMetadata

Returns a new instance of XpsTablesTrainingOperationMetadata.



4295
4296
4297
# File 'lib/google/apis/language_v1/classes.rb', line 4295

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_model_stageString

Current stage of creating model. Corresponds to the JSON property createModelStage

Returns:

  • (String)


4263
4264
4265
# File 'lib/google/apis/language_v1/classes.rb', line 4263

def create_model_stage
  @create_model_stage
end

#optimization_objectiveString

The optimization objective for model. Corresponds to the JSON property optimizationObjective

Returns:

  • (String)


4268
4269
4270
# File 'lib/google/apis/language_v1/classes.rb', line 4268

def optimization_objective
  @optimization_objective
end

#top_trialsArray<Google::Apis::LanguageV1::XpsTuningTrial>

This field is for training. When the operation is terminated successfully, AutoML Backend post this field to operation metadata in spanner. If the metadata has no trials returned, the training operation is supposed to be a failure. Corresponds to the JSON property topTrials



4276
4277
4278
# File 'lib/google/apis/language_v1/classes.rb', line 4276

def top_trials
  @top_trials
end

#train_budget_milli_node_hoursFixnum

Creating model budget. Corresponds to the JSON property trainBudgetMilliNodeHours

Returns:

  • (Fixnum)


4281
4282
4283
# File 'lib/google/apis/language_v1/classes.rb', line 4281

def train_budget_milli_node_hours
  @train_budget_milli_node_hours
end

#training_objective_pointsArray<Google::Apis::LanguageV1::XpsTrainingObjectivePoint>

This field records the training objective value with respect to time, giving insight into how the model architecture search is performing as training time elapses. Corresponds to the JSON property trainingObjectivePoints



4288
4289
4290
# File 'lib/google/apis/language_v1/classes.rb', line 4288

def training_objective_points
  @training_objective_points
end

#training_start_timeString

Timestamp when training process starts. Corresponds to the JSON property trainingStartTime

Returns:

  • (String)


4293
4294
4295
# File 'lib/google/apis/language_v1/classes.rb', line 4293

def training_start_time
  @training_start_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4300
4301
4302
4303
4304
4305
4306
4307
# File 'lib/google/apis/language_v1/classes.rb', line 4300

def update!(**args)
  @create_model_stage = args[:create_model_stage] if args.key?(:create_model_stage)
  @optimization_objective = args[:optimization_objective] if args.key?(:optimization_objective)
  @top_trials = args[:top_trials] if args.key?(:top_trials)
  @train_budget_milli_node_hours = args[:train_budget_milli_node_hours] if args.key?(:train_budget_milli_node_hours)
  @training_objective_points = args[:training_objective_points] if args.key?(:training_objective_points)
  @training_start_time = args[:training_start_time] if args.key?(:training_start_time)
end