Class: Google::Apis::LanguageV1::XpsTextComponentModel

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/language_v1/classes.rb,
lib/google/apis/language_v1/representations.rb,
lib/google/apis/language_v1/representations.rb

Overview

Component model.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ XpsTextComponentModel

Returns a new instance of XpsTextComponentModel.



4363
4364
4365
# File 'lib/google/apis/language_v1/classes.rb', line 4363

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#batch_prediction_model_gcs_uriString

The Cloud Storage resource path to hold batch prediction model. Corresponds to the JSON property batchPredictionModelGcsUri

Returns:

  • (String)


4317
4318
4319
# File 'lib/google/apis/language_v1/classes.rb', line 4317

def batch_prediction_model_gcs_uri
  @batch_prediction_model_gcs_uri
end

#online_prediction_model_gcs_uriString

The Cloud Storage resource path to hold online prediction model. Corresponds to the JSON property onlinePredictionModelGcsUri

Returns:

  • (String)


4322
4323
4324
# File 'lib/google/apis/language_v1/classes.rb', line 4322

def online_prediction_model_gcs_uri
  @online_prediction_model_gcs_uri
end

#partitionString

The partition where the model is deployed. Populated by uCAIP BE as part of online PredictRequest. Corresponds to the JSON property partition

Returns:

  • (String)


4328
4329
4330
# File 'lib/google/apis/language_v1/classes.rb', line 4328

def partition
  @partition
end

#serving_artifactGoogle::Apis::LanguageV1::XpsModelArtifactItem

A single model artifact item. Corresponds to the JSON property servingArtifact



4333
4334
4335
# File 'lib/google/apis/language_v1/classes.rb', line 4333

def serving_artifact
  @serving_artifact
end

#servo_model_nameString

The name of servo model. Populated by uCAIP BE as part of online PredictRequest. Corresponds to the JSON property servoModelName

Returns:

  • (String)


4339
4340
4341
# File 'lib/google/apis/language_v1/classes.rb', line 4339

def servo_model_name
  @servo_model_name
end

#submodel_nameString

The name of the trained NL submodel. Corresponds to the JSON property submodelName

Returns:

  • (String)


4344
4345
4346
# File 'lib/google/apis/language_v1/classes.rb', line 4344

def submodel_name
  @submodel_name
end

#submodel_typeString

The type of trained NL submodel Corresponds to the JSON property submodelType

Returns:

  • (String)


4349
4350
4351
# File 'lib/google/apis/language_v1/classes.rb', line 4349

def submodel_type
  @submodel_type
end

#tf_runtime_versionString

The fields below are only populated under uCAIP request scope. https://

cloud.google.com/ml-engine/docs/runtime-version-list Corresponds to the JSON property tfRuntimeVersion

Returns:

  • (String)


4355
4356
4357
# File 'lib/google/apis/language_v1/classes.rb', line 4355

def tf_runtime_version
  @tf_runtime_version
end

#version_numberFixnum

The servomatic model version number. Populated by uCAIP BE as part of online PredictRequest. Corresponds to the JSON property versionNumber

Returns:

  • (Fixnum)


4361
4362
4363
# File 'lib/google/apis/language_v1/classes.rb', line 4361

def version_number
  @version_number
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4368
4369
4370
4371
4372
4373
4374
4375
4376
4377
4378
# File 'lib/google/apis/language_v1/classes.rb', line 4368

def update!(**args)
  @batch_prediction_model_gcs_uri = args[:batch_prediction_model_gcs_uri] if args.key?(:batch_prediction_model_gcs_uri)
  @online_prediction_model_gcs_uri = args[:online_prediction_model_gcs_uri] if args.key?(:online_prediction_model_gcs_uri)
  @partition = args[:partition] if args.key?(:partition)
  @serving_artifact = args[:serving_artifact] if args.key?(:serving_artifact)
  @servo_model_name = args[:servo_model_name] if args.key?(:servo_model_name)
  @submodel_name = args[:submodel_name] if args.key?(:submodel_name)
  @submodel_type = args[:submodel_type] if args.key?(:submodel_type)
  @tf_runtime_version = args[:tf_runtime_version] if args.key?(:tf_runtime_version)
  @version_number = args[:version_number] if args.key?(:version_number)
end