Class: Google::Apis::LanguageV1::XpsTrainResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/language_v1/classes.rb,
lib/google/apis/language_v1/representations.rb,
lib/google/apis/language_v1/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ XpsTrainResponse

Returns a new instance of XpsTrainResponse.



4803
4804
4805
# File 'lib/google/apis/language_v1/classes.rb', line 4803

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#deployed_model_size_bytesFixnum

Estimated model size in bytes once deployed. Corresponds to the JSON property deployedModelSizeBytes

Returns:

  • (Fixnum)


4713
4714
4715
# File 'lib/google/apis/language_v1/classes.rb', line 4713

def deployed_model_size_bytes
  @deployed_model_size_bytes
end

#error_analysis_configsArray<Google::Apis::LanguageV1::XpsVisionErrorAnalysisConfig>

Optional vision model error analysis configuration. The field is set when model error analysis is enabled in the training request. The results of error analysis will be binded together with evaluation results (in the format of AnnotatedExample). Corresponds to the JSON property errorAnalysisConfigs



4721
4722
4723
# File 'lib/google/apis/language_v1/classes.rb', line 4721

def error_analysis_configs
  @error_analysis_configs
end

#evaluated_example_setGoogle::Apis::LanguageV1::XpsExampleSet

Set of examples or input sources. Corresponds to the JSON property evaluatedExampleSet



4726
4727
4728
# File 'lib/google/apis/language_v1/classes.rb', line 4726

def evaluated_example_set
  @evaluated_example_set
end

#evaluation_metrics_setGoogle::Apis::LanguageV1::XpsEvaluationMetricsSet

Specifies location of model evaluation metrics. Corresponds to the JSON property evaluationMetricsSet



4731
4732
4733
# File 'lib/google/apis/language_v1/classes.rb', line 4731

def evaluation_metrics_set
  @evaluation_metrics_set
end

#explanation_configsArray<Google::Apis::LanguageV1::XpsResponseExplanationSpec>

VisionExplanationConfig for XAI on test set. Optional for when XAI is enable in training request. Corresponds to the JSON property explanationConfigs



4737
4738
4739
# File 'lib/google/apis/language_v1/classes.rb', line 4737

def explanation_configs
  @explanation_configs
end

#image_classification_train_respGoogle::Apis::LanguageV1::XpsImageClassificationTrainResponse

Corresponds to the JSON property imageClassificationTrainResp



4742
4743
4744
# File 'lib/google/apis/language_v1/classes.rb', line 4742

def image_classification_train_resp
  @image_classification_train_resp
end

#image_object_detection_train_respGoogle::Apis::LanguageV1::XpsImageObjectDetectionModelSpec

Corresponds to the JSON property imageObjectDetectionTrainResp



4747
4748
4749
# File 'lib/google/apis/language_v1/classes.rb', line 4747

def image_object_detection_train_resp
  @image_object_detection_train_resp
end

#image_segmentation_train_respGoogle::Apis::LanguageV1::XpsImageSegmentationTrainResponse

Corresponds to the JSON property imageSegmentationTrainResp



4752
4753
4754
# File 'lib/google/apis/language_v1/classes.rb', line 4752

def image_segmentation_train_resp
  @image_segmentation_train_resp
end

#model_tokenString

Token that represents the trained model. This is considered immutable and is persisted in AutoML. xPS can put their own proto in the byte string, to e.g. point to the model checkpoints. The token is passed to other xPS APIs to refer to the model. Corresponds to the JSON property modelToken NOTE: Values are automatically base64 encoded/decoded in the client library.

Returns:

  • (String)


4761
4762
4763
# File 'lib/google/apis/language_v1/classes.rb', line 4761

def model_token
  @model_token
end

#speech_train_respGoogle::Apis::LanguageV1::XpsSpeechModelSpec

Corresponds to the JSON property speechTrainResp



4766
4767
4768
# File 'lib/google/apis/language_v1/classes.rb', line 4766

def speech_train_resp
  @speech_train_resp
end

#tables_train_respGoogle::Apis::LanguageV1::XpsTablesTrainResponse

Corresponds to the JSON property tablesTrainResp



4771
4772
4773
# File 'lib/google/apis/language_v1/classes.rb', line 4771

def tables_train_resp
  @tables_train_resp
end

#text_to_speech_train_respGoogle::Apis::LanguageV1::XpsTextToSpeechTrainResponse

TextToSpeech train response Corresponds to the JSON property textToSpeechTrainResp



4776
4777
4778
# File 'lib/google/apis/language_v1/classes.rb', line 4776

def text_to_speech_train_resp
  @text_to_speech_train_resp
end

#text_train_respGoogle::Apis::LanguageV1::XpsTextTrainResponse

Will only be needed for uCAIP from Beta. Corresponds to the JSON property textTrainResp



4781
4782
4783
# File 'lib/google/apis/language_v1/classes.rb', line 4781

def text_train_resp
  @text_train_resp
end

#translation_train_respGoogle::Apis::LanguageV1::XpsTranslationTrainResponse

Train response for translation. Corresponds to the JSON property translationTrainResp



4786
4787
4788
# File 'lib/google/apis/language_v1/classes.rb', line 4786

def translation_train_resp
  @translation_train_resp
end

#video_action_recognition_train_respGoogle::Apis::LanguageV1::XpsVideoActionRecognitionTrainResponse

Corresponds to the JSON property videoActionRecognitionTrainResp



4791
4792
4793
# File 'lib/google/apis/language_v1/classes.rb', line 4791

def video_action_recognition_train_resp
  @video_action_recognition_train_resp
end

#video_classification_train_respGoogle::Apis::LanguageV1::XpsVideoClassificationTrainResponse

Corresponds to the JSON property videoClassificationTrainResp



4796
4797
4798
# File 'lib/google/apis/language_v1/classes.rb', line 4796

def video_classification_train_resp
  @video_classification_train_resp
end

#video_object_tracking_train_respGoogle::Apis::LanguageV1::XpsVideoObjectTrackingTrainResponse

Corresponds to the JSON property videoObjectTrackingTrainResp



4801
4802
4803
# File 'lib/google/apis/language_v1/classes.rb', line 4801

def video_object_tracking_train_resp
  @video_object_tracking_train_resp
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4808
4809
4810
4811
4812
4813
4814
4815
4816
4817
4818
4819
4820
4821
4822
4823
4824
4825
4826
# File 'lib/google/apis/language_v1/classes.rb', line 4808

def update!(**args)
  @deployed_model_size_bytes = args[:deployed_model_size_bytes] if args.key?(:deployed_model_size_bytes)
  @error_analysis_configs = args[:error_analysis_configs] if args.key?(:error_analysis_configs)
  @evaluated_example_set = args[:evaluated_example_set] if args.key?(:evaluated_example_set)
  @evaluation_metrics_set = args[:evaluation_metrics_set] if args.key?(:evaluation_metrics_set)
  @explanation_configs = args[:explanation_configs] if args.key?(:explanation_configs)
  @image_classification_train_resp = args[:image_classification_train_resp] if args.key?(:image_classification_train_resp)
  @image_object_detection_train_resp = args[:image_object_detection_train_resp] if args.key?(:image_object_detection_train_resp)
  @image_segmentation_train_resp = args[:image_segmentation_train_resp] if args.key?(:image_segmentation_train_resp)
  @model_token = args[:model_token] if args.key?(:model_token)
  @speech_train_resp = args[:speech_train_resp] if args.key?(:speech_train_resp)
  @tables_train_resp = args[:tables_train_resp] if args.key?(:tables_train_resp)
  @text_to_speech_train_resp = args[:text_to_speech_train_resp] if args.key?(:text_to_speech_train_resp)
  @text_train_resp = args[:text_train_resp] if args.key?(:text_train_resp)
  @translation_train_resp = args[:translation_train_resp] if args.key?(:translation_train_resp)
  @video_action_recognition_train_resp = args[:video_action_recognition_train_resp] if args.key?(:video_action_recognition_train_resp)
  @video_classification_train_resp = args[:video_classification_train_resp] if args.key?(:video_classification_train_resp)
  @video_object_tracking_train_resp = args[:video_object_tracking_train_resp] if args.key?(:video_object_tracking_train_resp)
end