Class: Google::Apis::LanguageV1::XpsVideoBatchPredictOperationMetadata

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/language_v1/classes.rb,
lib/google/apis/language_v1/representations.rb,
lib/google/apis/language_v1/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ XpsVideoBatchPredictOperationMetadata

Returns a new instance of XpsVideoBatchPredictOperationMetadata.



5085
5086
5087
# File 'lib/google/apis/language_v1/classes.rb', line 5085

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#output_examplesArray<String>

All the partial batch prediction results that are completed at the moment. Output examples are sorted by completion time. The order will not be changed. Each output example should be the path of a single RecordIO file of AnnotatedExamples. Corresponds to the JSON property outputExamples

Returns:

  • (Array<String>)


5083
5084
5085
# File 'lib/google/apis/language_v1/classes.rb', line 5083

def output_examples
  @output_examples
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5090
5091
5092
# File 'lib/google/apis/language_v1/classes.rb', line 5090

def update!(**args)
  @output_examples = args[:output_examples] if args.key?(:output_examples)
end