Class: Google::Apis::LanguageV1::XpsVideoObjectTrackingTrainResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/language_v1/classes.rb,
lib/google/apis/language_v1/representations.rb,
lib/google/apis/language_v1/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ XpsVideoObjectTrackingTrainResponse

Returns a new instance of XpsVideoObjectTrackingTrainResponse.



5270
5271
5272
# File 'lib/google/apis/language_v1/classes.rb', line 5270

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#export_model_specGoogle::Apis::LanguageV1::XpsVideoExportModelSpec

Information of downloadable models that are pre-generated as part of training flow and will be persisted in AutoMl backend. Upon receiving ExportModel request from user, AutoMl backend can serve the pre-generated models to user if exists (by copying the files from internal path to user provided location), otherwise, AutoMl backend will call xPS ExportModel API to generate the model on the fly with the requesting format. Corresponds to the JSON property exportModelSpec



5257
5258
5259
# File 'lib/google/apis/language_v1/classes.rb', line 5257

def export_model_spec
  @export_model_spec
end

#model_artifact_specGoogle::Apis::LanguageV1::XpsVideoModelArtifactSpec

The fields below are only populated under uCAIP request scope.

Corresponds to the JSON property modelArtifactSpec



5262
5263
5264
# File 'lib/google/apis/language_v1/classes.rb', line 5262

def model_artifact_spec
  @model_artifact_spec
end

#train_cost_node_secondsFixnum

The actual train cost of creating this model, expressed in node seconds, i.e. 3,600 value in this field means 1 node hour. Corresponds to the JSON property trainCostNodeSeconds

Returns:

  • (Fixnum)


5268
5269
5270
# File 'lib/google/apis/language_v1/classes.rb', line 5268

def train_cost_node_seconds
  @train_cost_node_seconds
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5275
5276
5277
5278
5279
# File 'lib/google/apis/language_v1/classes.rb', line 5275

def update!(**args)
  @export_model_spec = args[:export_model_spec] if args.key?(:export_model_spec)
  @model_artifact_spec = args[:model_artifact_spec] if args.key?(:model_artifact_spec)
  @train_cost_node_seconds = args[:train_cost_node_seconds] if args.key?(:train_cost_node_seconds)
end