Class: Google::Apis::LanguageV1::XpsVisualization

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/language_v1/classes.rb,
lib/google/apis/language_v1/representations.rb,
lib/google/apis/language_v1/representations.rb

Overview

Visualization configurations for image explanation.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ XpsVisualization

Returns a new instance of XpsVisualization.



5396
5397
5398
# File 'lib/google/apis/language_v1/classes.rb', line 5396

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#clip_percent_lowerboundFloat

Excludes attributions below the specified percentile, from the highlighted areas. Defaults to 62. Corresponds to the JSON property clipPercentLowerbound

Returns:

  • (Float)


5357
5358
5359
# File 'lib/google/apis/language_v1/classes.rb', line 5357

def clip_percent_lowerbound
  @clip_percent_lowerbound
end

#clip_percent_upperboundFloat

Excludes attributions above the specified percentile from the highlighted areas. Using the clip_percent_upperbound and clip_percent_lowerbound together can be useful for filtering out noise and making it easier to see areas of strong attribution. Defaults to 99.9. Corresponds to the JSON property clipPercentUpperbound

Returns:

  • (Float)


5365
5366
5367
# File 'lib/google/apis/language_v1/classes.rb', line 5365

def clip_percent_upperbound
  @clip_percent_upperbound
end

#color_mapString

The color scheme used for the highlighted areas. Defaults to PINK_GREEN for Integrated Gradients attribution, which shows positive attributions in green and negative in pink. Defaults to VIRIDIS for XRAI attribution, which highlights the most influential regions in yellow and the least influential in blue. Corresponds to the JSON property colorMap

Returns:

  • (String)


5374
5375
5376
# File 'lib/google/apis/language_v1/classes.rb', line 5374

def color_map
  @color_map
end

#overlay_typeString

How the original image is displayed in the visualization. Adjusting the overlay can help increase visual clarity if the original image makes it difficult to view the visualization. Defaults to NONE. Corresponds to the JSON property overlayType

Returns:

  • (String)


5381
5382
5383
# File 'lib/google/apis/language_v1/classes.rb', line 5381

def overlay_type
  @overlay_type
end

#polarityString

Whether to only highlight pixels with positive contributions, negative or both. Defaults to POSITIVE. Corresponds to the JSON property polarity

Returns:

  • (String)


5387
5388
5389
# File 'lib/google/apis/language_v1/classes.rb', line 5387

def polarity
  @polarity
end

#typeString

Type of the image visualization. Only applicable to Integrated Gradients attribution. OUTLINES shows regions of attribution, while PIXELS shows per- pixel attribution. Defaults to OUTLINES. Corresponds to the JSON property type

Returns:

  • (String)


5394
5395
5396
# File 'lib/google/apis/language_v1/classes.rb', line 5394

def type
  @type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5401
5402
5403
5404
5405
5406
5407
5408
# File 'lib/google/apis/language_v1/classes.rb', line 5401

def update!(**args)
  @clip_percent_lowerbound = args[:clip_percent_lowerbound] if args.key?(:clip_percent_lowerbound)
  @clip_percent_upperbound = args[:clip_percent_upperbound] if args.key?(:clip_percent_upperbound)
  @color_map = args[:color_map] if args.key?(:color_map)
  @overlay_type = args[:overlay_type] if args.key?(:overlay_type)
  @polarity = args[:polarity] if args.key?(:polarity)
  @type = args[:type] if args.key?(:type)
end