Class: Google::Apis::LanguageV1::XpsConfidenceMetricsEntry
- Inherits:
-
Object
- Object
- Google::Apis::LanguageV1::XpsConfidenceMetricsEntry
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/language_v1/classes.rb,
lib/google/apis/language_v1/representations.rb,
lib/google/apis/language_v1/representations.rb
Overview
ConfidenceMetricsEntry includes generic precision, recall, f1 score etc. Next tag: 16.
Instance Attribute Summary collapse
-
#confidence_threshold ⇒ Float
Metrics are computed with an assumption that the model never return predictions with score lower than this value.
-
#f1_score ⇒ Float
The harmonic mean of recall and precision.
-
#f1_score_at1 ⇒ Float
The harmonic mean of recall_at1 and precision_at1.
-
#false_negative_count ⇒ Fixnum
The number of ground truth labels that are not matched by a model created label.
-
#false_positive_count ⇒ Fixnum
The number of model created labels that do not match a ground truth label.
-
#false_positive_rate ⇒ Float
False Positive Rate for the given confidence threshold.
-
#false_positive_rate_at1 ⇒ Float
The False Positive Rate when only considering the label that has the highest prediction score and not below the confidence threshold for each example.
-
#position_threshold ⇒ Fixnum
Metrics are computed with an assumption that the model always returns at most this many predictions (ordered by their score, descendingly), but they all still need to meet the confidence_threshold.
-
#precision ⇒ Float
Precision for the given confidence threshold.
-
#precision_at1 ⇒ Float
The precision when only considering the label that has the highest prediction score and not below the confidence threshold for each example.
-
#recall ⇒ Float
Recall (true positive rate) for the given confidence threshold.
-
#recall_at1 ⇒ Float
The recall (true positive rate) when only considering the label that has the highest prediction score and not below the confidence threshold for each example.
-
#true_negative_count ⇒ Fixnum
The number of labels that were not created by the model, but if they would, they would not match a ground truth label.
-
#true_positive_count ⇒ Fixnum
The number of model created labels that match a ground truth label.
Instance Method Summary collapse
-
#initialize(**args) ⇒ XpsConfidenceMetricsEntry
constructor
A new instance of XpsConfidenceMetricsEntry.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ XpsConfidenceMetricsEntry
Returns a new instance of XpsConfidenceMetricsEntry.
1840 1841 1842 |
# File 'lib/google/apis/language_v1/classes.rb', line 1840 def initialize(**args) update!(**args) end |
Instance Attribute Details
#confidence_threshold ⇒ Float
Metrics are computed with an assumption that the model never return
predictions with score lower than this value.
Corresponds to the JSON property confidenceThreshold
1765 1766 1767 |
# File 'lib/google/apis/language_v1/classes.rb', line 1765 def confidence_threshold @confidence_threshold end |
#f1_score ⇒ Float
The harmonic mean of recall and precision.
Corresponds to the JSON property f1Score
1770 1771 1772 |
# File 'lib/google/apis/language_v1/classes.rb', line 1770 def f1_score @f1_score end |
#f1_score_at1 ⇒ Float
The harmonic mean of recall_at1 and precision_at1.
Corresponds to the JSON property f1ScoreAt1
1775 1776 1777 |
# File 'lib/google/apis/language_v1/classes.rb', line 1775 def f1_score_at1 @f1_score_at1 end |
#false_negative_count ⇒ Fixnum
The number of ground truth labels that are not matched by a model created
label.
Corresponds to the JSON property falseNegativeCount
1781 1782 1783 |
# File 'lib/google/apis/language_v1/classes.rb', line 1781 def false_negative_count @false_negative_count end |
#false_positive_count ⇒ Fixnum
The number of model created labels that do not match a ground truth label.
Corresponds to the JSON property falsePositiveCount
1786 1787 1788 |
# File 'lib/google/apis/language_v1/classes.rb', line 1786 def false_positive_count @false_positive_count end |
#false_positive_rate ⇒ Float
False Positive Rate for the given confidence threshold.
Corresponds to the JSON property falsePositiveRate
1791 1792 1793 |
# File 'lib/google/apis/language_v1/classes.rb', line 1791 def false_positive_rate @false_positive_rate end |
#false_positive_rate_at1 ⇒ Float
The False Positive Rate when only considering the label that has the highest
prediction score and not below the confidence threshold for each example.
Corresponds to the JSON property falsePositiveRateAt1
1797 1798 1799 |
# File 'lib/google/apis/language_v1/classes.rb', line 1797 def false_positive_rate_at1 @false_positive_rate_at1 end |
#position_threshold ⇒ Fixnum
Metrics are computed with an assumption that the model always returns at most
this many predictions (ordered by their score, descendingly), but they all
still need to meet the confidence_threshold.
Corresponds to the JSON property positionThreshold
1804 1805 1806 |
# File 'lib/google/apis/language_v1/classes.rb', line 1804 def position_threshold @position_threshold end |
#precision ⇒ Float
Precision for the given confidence threshold.
Corresponds to the JSON property precision
1809 1810 1811 |
# File 'lib/google/apis/language_v1/classes.rb', line 1809 def precision @precision end |
#precision_at1 ⇒ Float
The precision when only considering the label that has the highest prediction
score and not below the confidence threshold for each example.
Corresponds to the JSON property precisionAt1
1815 1816 1817 |
# File 'lib/google/apis/language_v1/classes.rb', line 1815 def precision_at1 @precision_at1 end |
#recall ⇒ Float
Recall (true positive rate) for the given confidence threshold.
Corresponds to the JSON property recall
1820 1821 1822 |
# File 'lib/google/apis/language_v1/classes.rb', line 1820 def recall @recall end |
#recall_at1 ⇒ Float
The recall (true positive rate) when only considering the label that has the
highest prediction score and not below the confidence threshold for each
example.
Corresponds to the JSON property recallAt1
1827 1828 1829 |
# File 'lib/google/apis/language_v1/classes.rb', line 1827 def recall_at1 @recall_at1 end |
#true_negative_count ⇒ Fixnum
The number of labels that were not created by the model, but if they would,
they would not match a ground truth label.
Corresponds to the JSON property trueNegativeCount
1833 1834 1835 |
# File 'lib/google/apis/language_v1/classes.rb', line 1833 def true_negative_count @true_negative_count end |
#true_positive_count ⇒ Fixnum
The number of model created labels that match a ground truth label.
Corresponds to the JSON property truePositiveCount
1838 1839 1840 |
# File 'lib/google/apis/language_v1/classes.rb', line 1838 def true_positive_count @true_positive_count end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1845 1846 1847 1848 1849 1850 1851 1852 1853 1854 1855 1856 1857 1858 1859 1860 |
# File 'lib/google/apis/language_v1/classes.rb', line 1845 def update!(**args) @confidence_threshold = args[:confidence_threshold] if args.key?(:confidence_threshold) @f1_score = args[:f1_score] if args.key?(:f1_score) @f1_score_at1 = args[:f1_score_at1] if args.key?(:f1_score_at1) @false_negative_count = args[:false_negative_count] if args.key?(:false_negative_count) @false_positive_count = args[:false_positive_count] if args.key?(:false_positive_count) @false_positive_rate = args[:false_positive_rate] if args.key?(:false_positive_rate) @false_positive_rate_at1 = args[:false_positive_rate_at1] if args.key?(:false_positive_rate_at1) @position_threshold = args[:position_threshold] if args.key?(:position_threshold) @precision = args[:precision] if args.key?(:precision) @precision_at1 = args[:precision_at1] if args.key?(:precision_at1) @recall = args[:recall] if args.key?(:recall) @recall_at1 = args[:recall_at1] if args.key?(:recall_at1) @true_negative_count = args[:true_negative_count] if args.key?(:true_negative_count) @true_positive_count = args[:true_positive_count] if args.key?(:true_positive_count) end |