Class: Google::Apis::LanguageV1::XpsImageClassificationTrainResponse
- Inherits:
-
Object
- Object
- Google::Apis::LanguageV1::XpsImageClassificationTrainResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/language_v1/classes.rb,
lib/google/apis/language_v1/representations.rb,
lib/google/apis/language_v1/representations.rb
Instance Attribute Summary collapse
-
#class_count ⇒ Fixnum
Total number of classes.
-
#export_model_spec ⇒ Google::Apis::LanguageV1::XpsImageExportModelSpec
Information of downloadable models that are pre-generated as part of training flow and will be persisted in AutoMl backend.
-
#model_artifact_spec ⇒ Google::Apis::LanguageV1::XpsImageModelArtifactSpec
Stores the locations and related metadata of the model artifacts.
-
#model_serving_spec ⇒ Google::Apis::LanguageV1::XpsImageModelServingSpec
Serving specification for image models.
-
#stop_reason ⇒ String
Stop reason for training job, e.g.
-
#train_cost_in_node_time ⇒ String
The actual cost to create this model.
-
#train_cost_node_seconds ⇒ Fixnum
The actual training cost, expressed in node seconds.
Instance Method Summary collapse
-
#initialize(**args) ⇒ XpsImageClassificationTrainResponse
constructor
A new instance of XpsImageClassificationTrainResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ XpsImageClassificationTrainResponse
Returns a new instance of XpsImageClassificationTrainResponse.
2612 2613 2614 |
# File 'lib/google/apis/language_v1/classes.rb', line 2612 def initialize(**args) update!(**args) end |
Instance Attribute Details
#class_count ⇒ Fixnum
Total number of classes.
Corresponds to the JSON property classCount
2569 2570 2571 |
# File 'lib/google/apis/language_v1/classes.rb', line 2569 def class_count @class_count end |
#export_model_spec ⇒ Google::Apis::LanguageV1::XpsImageExportModelSpec
Information of downloadable models that are pre-generated as part of training
flow and will be persisted in AutoMl backend. Upon receiving ExportModel
request from user, AutoMl backend can serve the pre-generated models to user
if exists (by copying the files from internal path to user provided location),
otherwise, AutoMl backend will call xPS ExportModel API to generate the model
on the fly with the requesting format.
Corresponds to the JSON property exportModelSpec
2579 2580 2581 |
# File 'lib/google/apis/language_v1/classes.rb', line 2579 def export_model_spec @export_model_spec end |
#model_artifact_spec ⇒ Google::Apis::LanguageV1::XpsImageModelArtifactSpec
Stores the locations and related metadata of the model artifacts. Populated
for uCAIP requests only.
Corresponds to the JSON property modelArtifactSpec
2585 2586 2587 |
# File 'lib/google/apis/language_v1/classes.rb', line 2585 def model_artifact_spec @model_artifact_spec end |
#model_serving_spec ⇒ Google::Apis::LanguageV1::XpsImageModelServingSpec
Serving specification for image models.
Corresponds to the JSON property modelServingSpec
2590 2591 2592 |
# File 'lib/google/apis/language_v1/classes.rb', line 2590 def model_serving_spec @model_serving_spec end |
#stop_reason ⇒ String
Stop reason for training job, e.g. 'TRAIN_BUDGET_REACHED', 'MODEL_CONVERGED', '
MODEL_EARLY_STOPPED'.
Corresponds to the JSON property stopReason
2596 2597 2598 |
# File 'lib/google/apis/language_v1/classes.rb', line 2596 def stop_reason @stop_reason end |
#train_cost_in_node_time ⇒ String
The actual cost to create this model. - For edge type model, the cost is
expressed in node hour. - For cloud type model,the cost is expressed in
compute hour. - Populated for models created before GA. To be deprecated after
GA.
Corresponds to the JSON property trainCostInNodeTime
2604 2605 2606 |
# File 'lib/google/apis/language_v1/classes.rb', line 2604 def train_cost_in_node_time @train_cost_in_node_time end |
#train_cost_node_seconds ⇒ Fixnum
The actual training cost, expressed in node seconds. Populated for models
trained in node time.
Corresponds to the JSON property trainCostNodeSeconds
2610 2611 2612 |
# File 'lib/google/apis/language_v1/classes.rb', line 2610 def train_cost_node_seconds @train_cost_node_seconds end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2617 2618 2619 2620 2621 2622 2623 2624 2625 |
# File 'lib/google/apis/language_v1/classes.rb', line 2617 def update!(**args) @class_count = args[:class_count] if args.key?(:class_count) @export_model_spec = args[:export_model_spec] if args.key?(:export_model_spec) @model_artifact_spec = args[:model_artifact_spec] if args.key?(:model_artifact_spec) @model_serving_spec = args[:model_serving_spec] if args.key?(:model_serving_spec) @stop_reason = args[:stop_reason] if args.key?(:stop_reason) @train_cost_in_node_time = args[:train_cost_in_node_time] if args.key?(:train_cost_in_node_time) @train_cost_node_seconds = args[:train_cost_node_seconds] if args.key?(:train_cost_node_seconds) end |