Class: Google::Apis::LanguageV1::XpsImageObjectDetectionModelSpec
- Inherits:
-
Object
- Object
- Google::Apis::LanguageV1::XpsImageObjectDetectionModelSpec
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/language_v1/classes.rb,
lib/google/apis/language_v1/representations.rb,
lib/google/apis/language_v1/representations.rb
Instance Attribute Summary collapse
-
#class_count ⇒ Fixnum
Total number of classes.
-
#export_model_spec ⇒ Google::Apis::LanguageV1::XpsImageExportModelSpec
Information of downloadable models that are pre-generated as part of training flow and will be persisted in AutoMl backend.
-
#max_bounding_box_count ⇒ Fixnum
Max number of bounding box.
-
#model_artifact_spec ⇒ Google::Apis::LanguageV1::XpsImageModelArtifactSpec
Stores the locations and related metadata of the model artifacts.
-
#model_serving_spec ⇒ Google::Apis::LanguageV1::XpsImageModelServingSpec
Serving specification for image models.
-
#stop_reason ⇒ String
Stop reason for training job, e.g.
-
#train_cost_node_seconds ⇒ Fixnum
The actual train cost of creating this model, expressed in node seconds, i.e.
Instance Method Summary collapse
-
#initialize(**args) ⇒ XpsImageObjectDetectionModelSpec
constructor
A new instance of XpsImageObjectDetectionModelSpec.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ XpsImageObjectDetectionModelSpec
Returns a new instance of XpsImageObjectDetectionModelSpec.
2857 2858 2859 |
# File 'lib/google/apis/language_v1/classes.rb', line 2857 def initialize(**args) update!(**args) end |
Instance Attribute Details
#class_count ⇒ Fixnum
Total number of classes.
Corresponds to the JSON property classCount
2818 2819 2820 |
# File 'lib/google/apis/language_v1/classes.rb', line 2818 def class_count @class_count end |
#export_model_spec ⇒ Google::Apis::LanguageV1::XpsImageExportModelSpec
Information of downloadable models that are pre-generated as part of training
flow and will be persisted in AutoMl backend. Upon receiving ExportModel
request from user, AutoMl backend can serve the pre-generated models to user
if exists (by copying the files from internal path to user provided location),
otherwise, AutoMl backend will call xPS ExportModel API to generate the model
on the fly with the requesting format.
Corresponds to the JSON property exportModelSpec
2828 2829 2830 |
# File 'lib/google/apis/language_v1/classes.rb', line 2828 def export_model_spec @export_model_spec end |
#max_bounding_box_count ⇒ Fixnum
Max number of bounding box.
Corresponds to the JSON property maxBoundingBoxCount
2833 2834 2835 |
# File 'lib/google/apis/language_v1/classes.rb', line 2833 def max_bounding_box_count @max_bounding_box_count end |
#model_artifact_spec ⇒ Google::Apis::LanguageV1::XpsImageModelArtifactSpec
Stores the locations and related metadata of the model artifacts. Populated
for uCAIP requests only.
Corresponds to the JSON property modelArtifactSpec
2839 2840 2841 |
# File 'lib/google/apis/language_v1/classes.rb', line 2839 def model_artifact_spec @model_artifact_spec end |
#model_serving_spec ⇒ Google::Apis::LanguageV1::XpsImageModelServingSpec
Serving specification for image models.
Corresponds to the JSON property modelServingSpec
2844 2845 2846 |
# File 'lib/google/apis/language_v1/classes.rb', line 2844 def model_serving_spec @model_serving_spec end |
#stop_reason ⇒ String
Stop reason for training job, e.g. 'TRAIN_BUDGET_REACHED', 'MODEL_CONVERGED'.
Corresponds to the JSON property stopReason
2849 2850 2851 |
# File 'lib/google/apis/language_v1/classes.rb', line 2849 def stop_reason @stop_reason end |
#train_cost_node_seconds ⇒ Fixnum
The actual train cost of creating this model, expressed in node seconds, i.e.
3,600 value in this field means 1 node hour.
Corresponds to the JSON property trainCostNodeSeconds
2855 2856 2857 |
# File 'lib/google/apis/language_v1/classes.rb', line 2855 def train_cost_node_seconds @train_cost_node_seconds end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2862 2863 2864 2865 2866 2867 2868 2869 2870 |
# File 'lib/google/apis/language_v1/classes.rb', line 2862 def update!(**args) @class_count = args[:class_count] if args.key?(:class_count) @export_model_spec = args[:export_model_spec] if args.key?(:export_model_spec) @max_bounding_box_count = args[:max_bounding_box_count] if args.key?(:max_bounding_box_count) @model_artifact_spec = args[:model_artifact_spec] if args.key?(:model_artifact_spec) @model_serving_spec = args[:model_serving_spec] if args.key?(:model_serving_spec) @stop_reason = args[:stop_reason] if args.key?(:stop_reason) @train_cost_node_seconds = args[:train_cost_node_seconds] if args.key?(:train_cost_node_seconds) end |