Class: Google::Apis::LanguageV1::XpsSpeechPreprocessStats
- Inherits:
-
Object
- Object
- Google::Apis::LanguageV1::XpsSpeechPreprocessStats
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/language_v1/classes.rb,
lib/google/apis/language_v1/representations.rb,
lib/google/apis/language_v1/representations.rb
Instance Attribute Summary collapse
-
#data_errors ⇒ Array<Google::Apis::LanguageV1::XpsDataErrors>
Different types of data errors and the counts associated with them.
-
#num_human_labeled_examples ⇒ Fixnum
The number of rows marked HUMAN_LABELLED Corresponds to the JSON property
numHumanLabeledExamples. -
#num_logs_examples ⇒ Fixnum
The number of samples found in the previously recorded logs data.
-
#num_machine_transcribed_examples ⇒ Fixnum
The number of rows marked as MACHINE_TRANSCRIBED Corresponds to the JSON property
numMachineTranscribedExamples. -
#test_examples_count ⇒ Fixnum
The number of examples labelled as TEST by Speech xps server.
-
#test_sentences_count ⇒ Fixnum
The number of sentences in the test data set.
-
#test_words_count ⇒ Fixnum
The number of words in the test data set.
-
#train_examples_count ⇒ Fixnum
The number of examples labeled as TRAIN by Speech xps server.
-
#train_sentences_count ⇒ Fixnum
The number of sentences in the training data set.
-
#train_words_count ⇒ Fixnum
The number of words in the training data set.
Instance Method Summary collapse
-
#initialize(**args) ⇒ XpsSpeechPreprocessStats
constructor
A new instance of XpsSpeechPreprocessStats.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ XpsSpeechPreprocessStats
Returns a new instance of XpsSpeechPreprocessStats.
3669 3670 3671 |
# File 'lib/google/apis/language_v1/classes.rb', line 3669 def initialize(**args) update!(**args) end |
Instance Attribute Details
#data_errors ⇒ Array<Google::Apis::LanguageV1::XpsDataErrors>
Different types of data errors and the counts associated with them.
Corresponds to the JSON property dataErrors
3622 3623 3624 |
# File 'lib/google/apis/language_v1/classes.rb', line 3622 def data_errors @data_errors end |
#num_human_labeled_examples ⇒ Fixnum
The number of rows marked HUMAN_LABELLED
Corresponds to the JSON property numHumanLabeledExamples
3627 3628 3629 |
# File 'lib/google/apis/language_v1/classes.rb', line 3627 def num_human_labeled_examples @num_human_labeled_examples end |
#num_logs_examples ⇒ Fixnum
The number of samples found in the previously recorded logs data.
Corresponds to the JSON property numLogsExamples
3632 3633 3634 |
# File 'lib/google/apis/language_v1/classes.rb', line 3632 def num_logs_examples @num_logs_examples end |
#num_machine_transcribed_examples ⇒ Fixnum
The number of rows marked as MACHINE_TRANSCRIBED
Corresponds to the JSON property numMachineTranscribedExamples
3637 3638 3639 |
# File 'lib/google/apis/language_v1/classes.rb', line 3637 def num_machine_transcribed_examples @num_machine_transcribed_examples end |
#test_examples_count ⇒ Fixnum
The number of examples labelled as TEST by Speech xps server.
Corresponds to the JSON property testExamplesCount
3642 3643 3644 |
# File 'lib/google/apis/language_v1/classes.rb', line 3642 def test_examples_count @test_examples_count end |
#test_sentences_count ⇒ Fixnum
The number of sentences in the test data set.
Corresponds to the JSON property testSentencesCount
3647 3648 3649 |
# File 'lib/google/apis/language_v1/classes.rb', line 3647 def test_sentences_count @test_sentences_count end |
#test_words_count ⇒ Fixnum
The number of words in the test data set.
Corresponds to the JSON property testWordsCount
3652 3653 3654 |
# File 'lib/google/apis/language_v1/classes.rb', line 3652 def test_words_count @test_words_count end |
#train_examples_count ⇒ Fixnum
The number of examples labeled as TRAIN by Speech xps server.
Corresponds to the JSON property trainExamplesCount
3657 3658 3659 |
# File 'lib/google/apis/language_v1/classes.rb', line 3657 def train_examples_count @train_examples_count end |
#train_sentences_count ⇒ Fixnum
The number of sentences in the training data set.
Corresponds to the JSON property trainSentencesCount
3662 3663 3664 |
# File 'lib/google/apis/language_v1/classes.rb', line 3662 def train_sentences_count @train_sentences_count end |
#train_words_count ⇒ Fixnum
The number of words in the training data set.
Corresponds to the JSON property trainWordsCount
3667 3668 3669 |
# File 'lib/google/apis/language_v1/classes.rb', line 3667 def train_words_count @train_words_count end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3674 3675 3676 3677 3678 3679 3680 3681 3682 3683 3684 3685 |
# File 'lib/google/apis/language_v1/classes.rb', line 3674 def update!(**args) @data_errors = args[:data_errors] if args.key?(:data_errors) @num_human_labeled_examples = args[:num_human_labeled_examples] if args.key?(:num_human_labeled_examples) @num_logs_examples = args[:num_logs_examples] if args.key?(:num_logs_examples) @num_machine_transcribed_examples = args[:num_machine_transcribed_examples] if args.key?(:num_machine_transcribed_examples) @test_examples_count = args[:test_examples_count] if args.key?(:test_examples_count) @test_sentences_count = args[:test_sentences_count] if args.key?(:test_sentences_count) @test_words_count = args[:test_words_count] if args.key?(:test_words_count) @train_examples_count = args[:train_examples_count] if args.key?(:train_examples_count) @train_sentences_count = args[:train_sentences_count] if args.key?(:train_sentences_count) @train_words_count = args[:train_words_count] if args.key?(:train_words_count) end |