Class: Google::Apis::LanguageV1::XpsXpsOperationMetadata
- Inherits:
-
Object
- Object
- Google::Apis::LanguageV1::XpsXpsOperationMetadata
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/language_v1/classes.rb,
lib/google/apis/language_v1/representations.rb,
lib/google/apis/language_v1/representations.rb
Instance Attribute Summary collapse
-
#example_count ⇒ Fixnum
Optional.
-
#reporting_metrics ⇒ Google::Apis::LanguageV1::XpsReportingMetrics
Metrics for the operation.
-
#tables_training_operation_metadata ⇒ Google::Apis::LanguageV1::XpsTablesTrainingOperationMetadata
Corresponds to the JSON property
tablesTrainingOperationMetadata. -
#video_batch_predict_operation_metadata ⇒ Google::Apis::LanguageV1::XpsVideoBatchPredictOperationMetadata
Corresponds to the JSON property
videoBatchPredictOperationMetadata. -
#video_training_operation_metadata ⇒ Google::Apis::LanguageV1::XpsVideoTrainingOperationMetadata
Corresponds to the JSON property
videoTrainingOperationMetadata. -
#vision_training_operation_metadata ⇒ Google::Apis::LanguageV1::XpsVisionTrainingOperationMetadata
Corresponds to the JSON property
visionTrainingOperationMetadata.
Instance Method Summary collapse
-
#initialize(**args) ⇒ XpsXpsOperationMetadata
constructor
A new instance of XpsXpsOperationMetadata.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ XpsXpsOperationMetadata
Returns a new instance of XpsXpsOperationMetadata.
5452 5453 5454 |
# File 'lib/google/apis/language_v1/classes.rb', line 5452 def initialize(**args) update!(**args) end |
Instance Attribute Details
#example_count ⇒ Fixnum
Optional. XPS server can opt to provide example count of the long running
operation (e.g. training, data importing, batch prediction).
Corresponds to the JSON property exampleCount
5419 5420 5421 |
# File 'lib/google/apis/language_v1/classes.rb', line 5419 def example_count @example_count end |
#reporting_metrics ⇒ Google::Apis::LanguageV1::XpsReportingMetrics
Metrics for the operation. By the time the operation is terminated (whether
succeeded or failed) as returned from XPS, AutoML BE assumes the metrics are
finalized. AutoML BE transparently posts the metrics to Chemist if it's not
empty, regardless of the response content or error type. If user is supposed
to be charged in case of cancellation/error, this field should be set. In the
case where the type of LRO doesn't require any billing, this field should be
left unset.
Corresponds to the JSON property reportingMetrics
5430 5431 5432 |
# File 'lib/google/apis/language_v1/classes.rb', line 5430 def reporting_metrics @reporting_metrics end |
#tables_training_operation_metadata ⇒ Google::Apis::LanguageV1::XpsTablesTrainingOperationMetadata
Corresponds to the JSON property tablesTrainingOperationMetadata
5435 5436 5437 |
# File 'lib/google/apis/language_v1/classes.rb', line 5435 def @tables_training_operation_metadata end |
#video_batch_predict_operation_metadata ⇒ Google::Apis::LanguageV1::XpsVideoBatchPredictOperationMetadata
Corresponds to the JSON property videoBatchPredictOperationMetadata
5440 5441 5442 |
# File 'lib/google/apis/language_v1/classes.rb', line 5440 def @video_batch_predict_operation_metadata end |
#video_training_operation_metadata ⇒ Google::Apis::LanguageV1::XpsVideoTrainingOperationMetadata
Corresponds to the JSON property videoTrainingOperationMetadata
5445 5446 5447 |
# File 'lib/google/apis/language_v1/classes.rb', line 5445 def @video_training_operation_metadata end |
#vision_training_operation_metadata ⇒ Google::Apis::LanguageV1::XpsVisionTrainingOperationMetadata
Corresponds to the JSON property visionTrainingOperationMetadata
5450 5451 5452 |
# File 'lib/google/apis/language_v1/classes.rb', line 5450 def @vision_training_operation_metadata end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5457 5458 5459 5460 5461 5462 5463 5464 |
# File 'lib/google/apis/language_v1/classes.rb', line 5457 def update!(**args) @example_count = args[:example_count] if args.key?(:example_count) @reporting_metrics = args[:reporting_metrics] if args.key?(:reporting_metrics) @tables_training_operation_metadata = args[:tables_training_operation_metadata] if args.key?(:tables_training_operation_metadata) @video_batch_predict_operation_metadata = args[:video_batch_predict_operation_metadata] if args.key?(:video_batch_predict_operation_metadata) @video_training_operation_metadata = args[:video_training_operation_metadata] if args.key?(:video_training_operation_metadata) @vision_training_operation_metadata = args[:vision_training_operation_metadata] if args.key?(:vision_training_operation_metadata) end |